========
pymonome
========

monome application library for Python.

This package depends on aiosc, which is installable using pip.

See the examples directory for usage examples.

Make sure serialosc is running when you run the examples.  Have a
monome handy to test functionality.

Written by Artem Popov <artfwo@gmail.com>

Suggestions, bug reports, issues and/or pull requests are welcome.
